@@ -1,5 +1,6 @@
 """Assistant service implementation."""
 
+import inspect
 import json
 from pathlib import Path
 from typing import List, Union, Optional, Dict, Any, Literal
@@ -184,7 +185,11 @@ class AssistantService:
             Chat response or streaming response
         """
         pydantic_schema = None
-        if issubclass(request.output_schema, BaseModel):
+        if (
+            request.output_schema is not None
+            and inspect.isclass(request.output_schema)
+            and issubclass(request.output_schema, BaseModel)
+        ):
             pydantic_schema = deepcopy(request.output_schema)
             request.output_schema = request.output_schema.model_json_schema()
 
